@@ -6,6 +6,9 @@
 /* Bug report URL. */
 #define BUG_REPORT_URL ""
 
+/* Define if we have libxml2 */
+/* #undef CLANG_HAVE_LIBXML */
+
 /* Relative directory for resource files */
 #define CLANG_RESOURCE_DIR ""
 
@@ -61,15 +64,18 @@
 #define HAVE_CEILF 1
 
 /* Define if the neat program is available */
-#define HAVE_CIRCO 1
+/* #undef HAVE_CIRCO */
 
 /* Define to 1 if you have the `closedir' function. */
 #define HAVE_CLOSEDIR 1
 
+/* Define to 1 if you have the <cxxabi.h> header file. */
+#define HAVE_CXXABI_H 1
+
 /* Define to 1 if you have the <CrashReporterClient.h> header file. */
 #undef HAVE_CRASHREPORTERCLIENT_H
 
-/* Define if __crashreporter_info__ exists. */
+/* can use __crashreporter_info__ */
 #undef HAVE_CRASHREPORTER_INFO
 
 /* Define to 1 if you have the <ctype.h> header file. */
@@ -102,10 +108,10 @@
 /* #undef HAVE_DL_H */
 
 /* Define if the dot program is available */
-#define HAVE_DOT 1
+/* #undef HAVE_DOT */
 
 /* Define if the dotty program is available */
-#define HAVE_DOTTY 1
+/* #undef HAVE_DOTTY */
 
 /* Define if you have the _dyld_func_lookup function. */
 #undef HAVE_DYLD
@@ -123,7 +129,7 @@
 #define HAVE_FCNTL_H 1
 
 /* Define if the neat program is available */
-#define HAVE_FDP 1
+/* #undef HAVE_FDP */
 
 /* Define to 1 if you have the <fenv.h> header file. */
 #define HAVE_FENV_H 1
@@ -143,6 +149,24 @@
 /* Define to 1 if you have the `floorf' function. */
 #define HAVE_FLOORF 1
 
+/* Define to 1 if you have the `log' function. */
+#define HAVE_LOG 1
+
+/* Define to 1 if you have the `log2' function. */
+#define HAVE_LOG2 1
+
+/* Define to 1 if you have the `log10' function. */
+#define HAVE_LOG10 1
+
+/* Define to 1 if you have the `exp' function. */
+#define HAVE_EXP 1
+
+/* Define to 1 if you have the `exp2' function. */
+#define HAVE_EXP2 1
+
+/* Define to 1 if you have the `exp10' function. */
+/* #undef HAVE_EXP10 */
+
 /* Define to 1 if you have the `fmodf' function. */
 #define HAVE_FMODF 1
 
@@ -209,6 +233,9 @@
 /* Define to 1 if you have the `udis86' library (-ludis86). */
 #undef HAVE_LIBUDIS86
 
+/* Define to 1 if you have the 'z' library (-lz). */
+#define HAVE_LIBZ 1
+
 /* Define to 1 if you have the <limits.h> header file. */
 #define HAVE_LIMITS_H 1
 
@@ -278,7 +305,7 @@
 #define HAVE_NEARBYINTF 1
 
 /* Define if the neat program is available */
-#define HAVE_NEATO 1
+/* #undef HAVE_NEATO */
 
 /* Define to 1 if you have the `opendir' function. */
 #define HAVE_OPENDIR 1
@@ -442,7 +469,7 @@
 #define HAVE_SYS_TYPES_H 1
 
 /* Define to 1 if you have the <sys/uio.h> header file. */
-/* #undef HAVE_SYS_UIO_H */
+#define HAVE_SYS_UIO_H 1
 
 /* Define to 1 if you have <sys/wait.h> that is POSIX.1 compatible. */
 #define HAVE_SYS_WAIT_H 1
@@ -451,7 +478,7 @@
 #define HAVE_TERMIOS_H 1
 
 /* Define if the neat program is available */
-#define HAVE_TWOPI 1
+/* #undef HAVE_TWOPI */
 
 /* Define to 1 if the system has the type `uint64_t'. */
 #define HAVE_UINT64_T 1
@@ -472,11 +499,14 @@
 /* #undef HAVE_WINDOWS_H */
 
 /* Define to 1 if you have the `writev' function. */
-/* #undef HAVE_WRITEV */
+#define HAVE_WRITEV 1
 
 /* Define if the xdot.py program is available */
 /* #undef HAVE_XDOT_PY */
 
+/* Define to 1 if you have the <zlib.h> header file. */
+#define HAVE_ZLIB_H 1
+
 /* Have host's _alloca */
 /* #undef HAVE__ALLOCA */
 
@@ -541,7 +571,7 @@
 /* #undef LLVM_DATADIR */
 
 /* Target triple LLVM will generate code for by default */
-#define LLVM_DEFAULT_TARGET_TRIPLE "powerpc-unknown-openbsd5.3"
+#define LLVM_DEFAULT_TARGET_TRIPLE "i386-unknown-openbsd5.4"
 
 /* Installation directory for documentation */
 /* #undef LLVM_DOCSDIR */
@@ -549,6 +579,9 @@
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
 
+/* Define if zlib compression is available */
+#define LLVM_ENABLE_ZLIB 1
+
 /* Installation directory for config files */
 /* #undef LLVM_ETCDIR */
 
@@ -556,7 +589,7 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOSTTRIPLE "powerpc-unknown-openbsd5.3"
+#define LLVM_HOST_TRIPLE "i386-unknown-openbsd5.4"
 
 /* Installation directory for include files */
 /* #undef LLVM_INCLUDEDIR */
@@ -571,25 +604,25 @@
 /* #undef LLVM_MANDIR */
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH PowerPC
+#define LLVM_NATIVE_ARCH X86
 
 /* LLVM name for the native AsmParser init function, if available */
-/* #undef LLVM_NATIVE_ASMPARSER */
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeX86AsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializePowerPCAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeX86AsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-/* #undef LLVM_NATIVE_DISASSEMBLER */
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeX86Disassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializePowerPCTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeX86Target
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializePowerPCTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeX86TargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializePowerPCTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeX86TargetMC
 
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
@@ -598,16 +631,16 @@
 /* #undef LLVM_ON_WIN32 */
 
 /* Define to path to circo program if found or 'echo circo' otherwise */
-#define LLVM_PATH_CIRCO "/usr/local/bin/circo"
+/* #undef LLVM_PATH_CIRCO */
 
 /* Define to path to dot program if found or 'echo dot' otherwise */
-#define LLVM_PATH_DOT "/usr/local/bin/dot"
+/* #undef LLVM_PATH_DOT */
 
 /* Define to path to dotty program if found or 'echo dotty' otherwise */
-#define LLVM_PATH_DOTTY "/usr/local/bin/dotty"
+/* #undef LLVM_PATH_DOTTY */
 
 /* Define to path to fdp program if found or 'echo fdp' otherwise */
-#define LLVM_PATH_FDP "/usr/local/bin/fdp"
+/* #undef LLVM_PATH_FDP */
 
 /* Define to path to Graphviz program if found or 'echo Graphviz' otherwise */
 /* #undef LLVM_PATH_GRAPHVIZ */
@@ -616,10 +649,10 @@
 /* #undef LLVM_PATH_GV */
 
 /* Define to path to neato program if found or 'echo neato' otherwise */
-#define LLVM_PATH_NEATO "/usr/local/bin/neato"
+/* #undef LLVM_PATH_NEATO */
 
 /* Define to path to twopi program if found or 'echo twopi' otherwise */
-#define LLVM_PATH_TWOPI "/usr/local/bin/twopi"
+/* #undef LLVM_PATH_TWOPI */
 
 /* Define to path to xdot.py program if found or 'echo xdot.py' otherwise */
 /* #undef LLVM_PATH_XDOT_PY */
@@ -637,7 +670,7 @@
 #define LLVM_VERSION_MAJOR 3
 
 /* Minor version of the LLVM API */
-#define LLVM_VERSION_MINOR 2
+#define LLVM_VERSION_MINOR 3
 
 /* Define if the OS needs help to load dependent libraries for dlopen(). */
 /* #undef LTDL_DLOPEN_DEPLIBS */
@@ -670,13 +703,13 @@
 #define PACKAGE_NAME "LLVM"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "LLVM 3.2"
+#define PACKAGE_STRING "LLVM 3.3"
 
 /* Define to the one symbol short name of this package. */
 #undef PACKAGE_TARNAME
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "3.2"
+#define PACKAGE_VERSION "3.3"
 
 /* Define as the return type of signal handlers (`int' or `void'). */
 #define RETSIGTYPE void
