@@ -26,7 +26,7 @@
 /* #undef LLVM_DATADIR */
 
 /* Target triple LLVM will generate code for by default */
-#define LLVM_DEFAULT_TARGET_TRIPLE "sparc64-unknown-openbsd5.3"
+#define LLVM_DEFAULT_TARGET_TRIPLE "mips64-unknown-openbsd5.5"
 
 /* Installation directory for documentation */
 /* #undef LLVM_DOCSDIR */
@@ -38,10 +38,10 @@
 /* #undef LLVM_ETCDIR */
 
 /* Has gcc/MSVC atomic intrinsics */
-#define LLVM_HAS_ATOMICS 1
+#define LLVM_HAS_ATOMICS 0
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOSTTRIPLE "sparc64-unknown-openbsd5.3"
+#define LLVM_HOST_TRIPLE "mips64-unknown-openbsd5.5"
 
 /* Installation directory for include files */
 /* #undef LLVM_INCLUDEDIR */
@@ -56,25 +56,25 @@
 /* #undef LLVM_MANDIR */
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH Sparc
+#define LLVM_NATIVE_ARCH Mips
 
 /* LLVM name for the native AsmParser init function, if available */
-/* #undef LLVM_NATIVE_ASMPARSER */
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeSparcAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-/* #undef LLVM_NATIVE_DISASSEMBLER */
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeSparcTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeSparcTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeSparcTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
 
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
@@ -112,10 +112,19 @@
 /* Installation prefix directory */
 #define LLVM_PREFIX "/usr/local"
 
+/* Define if we have the Intel JIT API runtime support library */
+/* #undef LLVM_USE_INTEL_JITEVENTS */
+
+/* Define if we have the oprofile JIT-support library */
+/* #undef LLVM_USE_OPROFILE */
+
 /* Major version of the LLVM API */
 #define LLVM_VERSION_MAJOR 3
 
 /* Minor version of the LLVM API */
-#define LLVM_VERSION_MINOR 2
+#define LLVM_VERSION_MINOR 3
+
+/* Define to 1 if you have the <sanitizer/msan_interface.h> header file. */
+/* #undef HAVE_SANITIZER_MSAN_INTERFACE_H */
 
 #endif
